Valvrare Team Scraper Web UI

## Nhật ký hoạt động

Sẵn sàng. Đang chờ nhiệm vụ...

## Thư viện & Lịch sử

## Tên truyện

Tác giả: -

Trạng thái: -

Chương -
Chữ -
Lượt xem -

### Nội dung

## Chọn chương để tải

Đang tải danh sách chương...

## Tải truyện

Định dạng:
EPUB PDF HTML Markdown Text MP3 (Audiobook) MP3 (Audio Drama - AI Script)
Số tác vụ song song:
Thư mục đầu ra (để trống để tự động):
Bỏ qua minh họa

## Cài đặt hệ thống

Số luồng tải song song (Worker): Số lượng truyện có thể tải cùng lúc.
Thư mục đầu ra mặc định:

## Nhập danh sách truyện

Nhập danh sách URL hoặc Slug (mỗi dòng một mục):